"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var React = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _clsx = _interopRequireDefault(require("clsx"));

var _utils = require("@material-ui/utils");

var _unstyled = require("@material-ui/unstyled");

var _styledEngine = require("@material-ui/styled-engine");

var _capitalize = _interopRequireDefault(require("../utils/capitalize"));

var _useThemeProps = _interopRequireDefault(require("../styles/useThemeProps"));

var _experimentalStyled = _interopRequireDefault(require("../styles/experimentalStyled"));

var _circularProgressClasses = _interopRequireWildcard(require("./circularProgressClasses"));

const SIZE = 44;
const circularRotateKeyframe = (0, _styledEngine.keyframes)`
0% {
  transform: rotate(0deg);
}
100% {
  transform: rotate(360deg);
}
`;
const circularDashKeyframe = (0, _styledEngine.keyframes)`
0% {
  stroke-dasharray: 1px, 200px;
  stroke-dashoffset: 0px;
}
50% {
  stroke-dasharray: 100px, 200px;
  stroke-dashoffset: -15px;
}
100% {
  stroke-dasharray: 100px, 200px;
  stroke-dashoffset: -125px;
}
`;

const overridesResolver = (props, styles) => {
  const {
    styleProps
  } = props;
  return (0, _utils.deepmerge)(styles.root || {}, (0, _extends2.default)({}, styles[styleProps.variant], styles[`color${(0, _capitalize.default)(styleProps.color)}`], {
    [`& .${_circularProgressClasses.default.svg}`]: styles.svg,
    [`& .${_circularProgressClasses.default.circle}`]: (0, _extends2.default)({}, styles.circle, styles[`circle${(0, _capitalize.default)(styleProps.variant)}`], styleProps.disableShrink && styles.circleDisableShrink)
  }));
};

const useUtilityClasses = styleProps => {
  const {
    classes,
    variant,
    color,
    disableShrink
  } = styleProps;
  const slots = {
    root: ['root', variant, `color${(0, _capitalize.default)(color)}`],
    svg: ['svg'],
    circle: ['circle', `circle${(0, _capitalize.default)(variant)}`, disableShrink && 'circleDisableShrink']
  };
  return (0, _unstyled.unstable_composeClasses)(slots, _circularProgressClasses.getCircularProgressUtilityClass, classes);
}; // This `styled()` function invokes keyframes. `styled-components` only supports keyframes
// in string templates. Do not convert these styles in JS object as it will break.


const CircularProgressRoot = (0, _experimentalStyled.default)('span', {}, {
  name: 'MuiCircularProgress',
  slot: 'Root',
  overridesResolver
})`
  display: inline-block;

  transition: ${({
  styleProps,
  theme
}) => styleProps.variant === 'determinate' ? theme.transitions.create('transform') : undefined};

  animation-name: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && circularRotateKeyframe};
  animation-duration: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && '1.4s'};
  animation-timing-function: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && 'linear'};
  animation-iteration-count: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && 'infinite'};
    
  color: ${({
  styleProps,
  theme
}) => styleProps.color === 'primary' || styleProps.color === 'secondary' ? theme.palette[styleProps.color].main : undefined};
`;
const CircularProgressSVG = (0, _experimentalStyled.default)('svg', {}, {
  name: 'MuiCircularProgress',
  slot: 'Svg'
})({
  /* Styles applied to the svg element. */
  display: 'block' // Keeps the progress centered

}); // This `styled()` function invokes keyframes. `styled-components` only supports keyframes
// in string templates. Do not convert these styles in JS object as it will break.

const CircularProgressCircle = (0, _experimentalStyled.default)('circle', {}, {
  name: 'MuiCircularProgress',
  slot: 'Circle'
})`
  stroke: currentColor;

  transition: ${({
  styleProps,
  theme
}) => styleProps.variant === 'determinate' ? theme.transitions.create('stroke-dashoffset') : undefined};

  animation-name: ${({
  styleProps
}) => {
  if (styleProps.disableShrink) {
    return 'none';
  }

  return styleProps.variant === 'indeterminate' ? circularDashKeyframe : undefined;
}};
  animation-duration: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && '1.4s'};
  animation-timing-function: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && 'ease-in-out'};
  animation-iteration-count: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && 'infinite'};
  stroke-dasharray: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && '80px, 200px'};
  stroke-dashoffset: ${({
  styleProps
}) => styleProps.variant === 'indeterminate' && '0px'};
`;
/**
 * ## ARIA
 *
 * If the progress bar is describing the loading progress of a particular region of a page,
 * you should use `aria-describedby` to point to the progress bar, and set the `aria-busy`
 * attribute to `true` on that region until it has finished loading.
 */

const CircularProgress = /*#__PURE__*/React.forwardRef(function CircularProgress(inProps, ref) {
  const props = (0, _useThemeProps.default)({
    props: inProps,
    name: 'MuiCircularProgress'
  });
  const {
    className,
    color = 'primary',
    disableShrink = false,
    size = 40,
    style,
    thickness = 3.6,
    value = 0,
    variant = 'indeterminate'
  } = props,
        other = (0, _objectWithoutPropertiesLoose2.default)(props, ["className", "color", "disableShrink", "size", "style", "thickness", "value", "variant"]);
  const styleProps = (0, _extends2.default)({}, props, {
    color,
    disableShrink,
    size,
    thickness,
    value,
    variant
  });
  const classes = useUtilityClasses(styleProps);
  const circleStyle = {};
  const rootStyle = {};
  const rootProps = {};

  if (variant === 'determinate') {
    const circumference = 2 * Math.PI * ((SIZE - thickness) / 2);
    circleStyle.strokeDasharray = circumference.toFixed(3);
    rootProps['aria-valuenow'] = Math.round(value);
    circleStyle.strokeDashoffset = `${((100 - value) / 100 * circumference).toFixed(3)}px`;
    rootStyle.transform = 'rotate(-90deg)';
  }

  return /*#__PURE__*/React.createElement(CircularProgressRoot, (0, _extends2.default)({
    className: (0, _clsx.default)(classes.root, className),
    style: (0, _extends2.default)({
      width: size,
      height: size
    }, rootStyle, style),
    styleProps: styleProps,
    ref: ref,
    role: "progressbar"
  }, rootProps, other), /*#__PURE__*/React.createElement(CircularProgressSVG, {
    className: classes.svg,
    styleProps: styleProps,
    viewBox: `${SIZE / 2} ${SIZE / 2} ${SIZE} ${SIZE}`
  }, /*#__PURE__*/React.createElement(CircularProgressCircle, {
    className: classes.circle,
    style: circleStyle,
    styleProps: styleProps,
    cx: SIZE,
    cy: SIZE,
    r: (SIZE - thickness) / 2,
    fill: "none",
    strokeWidth: thickness
  })));
});
process.env.NODE_ENV !== "production" ? CircularProgress.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit the d.ts file and run "yarn proptypes"     |
  // ----------------------------------------------------------------------

  /**
   * Override or extend the styles applied to the component.
   */
  classes: _propTypes.default.object,

  /**
   * @ignore
   */
  className: _propTypes.default.string,

  /**
   * The color of the component. It supports those theme colors that make sense for this component.
   * @default 'primary'
   */
  color: _propTypes.default.oneOf(['inherit', 'primary', 'secondary']),

  /**
   * If `true`, the shrink animation is disabled.
   * This only works if variant is `indeterminate`.
   * @default false
   */
  disableShrink: (0, _utils.chainPropTypes)(_propTypes.default.bool, props => {
    if (props.disableShrink && props.variant && props.variant !== 'indeterminate') {
      return new Error('Material-UI: You have provided the `disableShrink` prop ' + 'with a variant other than `indeterminate`. This will have no effect.');
    }

    return null;
  }),

  /**
   * The size of the component.
   * If using a number, the pixel unit is assumed.
   * If using a string, you need to provide the CSS unit, e.g '3rem'.
   * @default 40
   */
  size: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),

  /**
   * @ignore
   */
  style: _propTypes.default.object,

  /**
   * The system prop that allows defining system overrides as well as additional CSS styles.
   */
  sx: _propTypes.default.object,

  /**
   * The thickness of the circle.
   * @default 3.6
   */
  thickness: _propTypes.default.number,

  /**
   * The value of the progress indicator for the determinate variant.
   * Value between 0 and 100.
   * @default 0
   */
  value: _propTypes.default.number,

  /**
   * The variant to use.
   * Use indeterminate when there is no progress value.
   * @default 'indeterminate'
   */
  variant: _propTypes.default.oneOf(['determinate', 'indeterminate'])
} : void 0;
var _default = CircularProgress;
exports.default = _default;